@@ -1,6 +1,7 @@
 """
 Command generate-workflow
 """
+import json
 import sys
 
 import click
@@ -23,7 +24,7 @@ from tcd_pipeline import pipeline as pipeline_tool
   help="Branch name or Tag name"
   )
 @click.option("--change",
-  help="Changed file",
+  help='Changed file(s). Example Dockerfile  or JSON format ["Dockerfile","README.md"]',
   multiple=True,
   default=[list]
   )
@@ -48,7 +49,17 @@ def generate_workflows(pipelines: str,
 
     # Add change to fact
     for file in change:
-        fact.get("changes").append(file)
+        if file.__contains__("["):
+            # for item_file in re.sub(r"[\[\]]", "", file).split(","):
+            #     fact.get("changes").append(item_file)
+            try:
+                file_list: list[str] = json.loads(file)
+                for item in file_list:
+                    fact.get("changes").append(item)
+            except json.decoder.JSONDecodeError:
+                pass
+        else:
+            fact.get("changes").append(file)
 
     try:
         pipeline_tool.generate_workflows(
